@@ -216,7 +216,7 @@ class Interpreter(object):
         elif tok is EOF:
             raise LogoEndOfCode("The end of the code block was not expected")
 
-        elif type(tok) is not str:
+        elif not isinstance(tok, basestring):
             # Some other fundamental type (usually int or float)
             return tok
 
@@ -265,7 +265,8 @@ class Interpreter(object):
                 else:
                     self.tokenizer.next()
                 if self.special_forms.has_key(func.lower()):
-                    val = self.special_forms[func.lower()](self, greedy=True)
+                    special_form = self.special_forms[func.lower()]
+                    val = special_form(self, greedy=True)
                     next_tok = self.tokenizer.next()
                     if next_tok != ')':
                         raise LogoSyntaxError("')' expected")
@@ -293,7 +294,8 @@ class Interpreter(object):
             if not reader.is_word(tok):
                 raise LogoSyntaxError("Unknown token: %r" % tok)
             if tok.lower() in self.special_forms:
-                val = self.special_forms[tok.lower()](self, greedy=False)
+                special_form = self.special_forms[tok.lower()]
+                val = special_form(self, greedy=False)
                 return val
             else:
                 func_name = tok
@@ -420,7 +422,7 @@ class Interpreter(object):
                     val = self.eval(block)
                 except LogoContinue:
                     pass
-        except LogoStop:
+        except LogoBreak:
             pass
         return val
 
@@ -430,8 +432,12 @@ class Interpreter(object):
     def special_tell(self, greedy):
         obj = self.expr()
         tok = self.tokenizer.peek()
-        if tok == '[':
-            block = self.expr()
+        if tok == '[' or isinstance(tok, list):
+            if tok == '[':
+                block = self.expr()
+            else:
+                block = tok
+                self.tokenizer.next()
             interp = self.new()
             interp.push_actor(obj)
             try:
@@ -658,7 +664,10 @@ class Interpreter(object):
                 try:
                     v = self.expr_top()
                 except LogoError, e:
-                    print e.description, ':', e
+                    if str(e) != str(e.description):
+                        print e.description, ':', e
+                    else:
+                        print e
                     v = None
                 except KeyboardInterrupt:
                     if tokenizer.context:
